@@ -320,6 +320,7 @@ void Folder::slotRunEtagJob()
         // sync if it's different.
 
         _requestEtagJob = new RequestEtagJob(account, remotePath(), this);
+        _requestEtagJob->setTimeout(60*1000);
         // check if the etag is different
         QObject::connect(_requestEtagJob, SIGNAL(etagRetreived(QString)), this, SLOT(etagRetreived(QString)));
         FolderMan::instance()->slotScheduleETagJob(alias(), _requestEtagJob);
@@ -694,6 +695,10 @@ void Folder::wipe()
 
 bool Folder::setIgnoredFiles()
 {
+    // Note: Doing this on each sync run and on Folder construction is
+    // unnecessary, because _engine->excludedFiles() persists between
+    // sync runs. This is not a big problem because ExcludedFiles maintains
+    // a QSet of files to load.
     ConfigFile cfg;
     QString systemList = cfg.excludeFile(ConfigFile::SystemScope);
     if( QFile::exists(systemList) ) {
@@ -915,7 +920,7 @@ void Folder::slotFolderDiscovered(bool, QString folderName)
 // and hand the result over to the progress dispatcher.
 void Folder::slotTransmissionProgress(const ProgressInfo &pi)
 {
-    if( !pi.hasStarted() ) {
+    if( !pi.isUpdatingEstimates() ) {
         // this is the beginning of a sync, set the warning level to 0
         _syncResult.setWarnCount(0);
     }
